@@ -7,7 +7,6 @@ import jwplatform
 
 from urllib.parse import quote
 
-
 def test_required_parameters_present():
 
     KEY = 'api_key'
@@ -33,7 +32,7 @@ def test_required_parameters_present():
     assert params['api_format'] == 'json'
 
     assert 'api_kit' in params
-    assert params['api_kit'] == 'py-{}'.format(jwplatform.__version__)
+    assert params['api_kit'] == 'py-{}'.format(jwplatform.version.__version__)
 
     assert 'api_signature' in params
 
@@ -77,7 +76,7 @@ SIGNATURE_TEST_CASES = [
             't1': True,
             'n0': None,
         },
-        'expected_query_string': 'a=1&api_format=json&api_key=API_KEY_VALUE&api_kit=py-2.0.0'
+        'expected_query_string': f'a=1&api_format=json&api_key=API_KEY_VALUE&api_kit=py-{jwplatform.version.__version__}'
                                  '&api_nonce=API_NONCE_VALUE&api_timestamp=API_TIMESTAMP_VALUE'
                                  '&b=two&c3=Param%203&n0=None&t1=True&%E2%9D%84=%E2%9B%84',
     },
@@ -92,7 +91,7 @@ SIGNATURE_TEST_CASES = [
             'test_array1': [1, 2, 3, 4],
             'test_array2': ["test item1", "test item2"],
         },
-        'expected_query_string': 'a=1&api_format=json&api_key=API_KEY_VALUE&api_kit=py-2.0.0'
+        'expected_query_string': f'a=1&api_format=json&api_key=API_KEY_VALUE&api_kit=py-{jwplatform.version.__version__}'
                                  '&api_nonce=API_NONCE_VALUE&api_timestamp=API_TIMESTAMP_VALUE'
                                  '&b=two&c3=Param%203&n0=None&t1=True&test_array1=1&test_array1=2'
                                  '&test_array1=3&test_array1=4&test_array2=test%20item1'
